@@ -2,11 +2,12 @@
 #this repository contains the full copyright notices and license terms.
 {
     'name': 'Company Work Time',
+    'name_bg_BG': 'Работно време на фирма',
     'name_de_DE': 'Unternehmen Arbeitszeit',
     'name_es_CO': 'Tiempo de Trabajo en la Compañía',
     'name_es_ES': 'Tiempo de trabajo en la empresa',
     'name_fr_FR': 'Temps de travail dans la société',
-    'version': '1.6.0',
+    'version': '2.0.0',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -20,6 +21,7 @@
         'company.xml',
     ],
     'translation': [
+        'bg_BG.csv',
         'de_DE.csv',
         'es_CO.csv',
         'es_ES.csv',
